import os
import random
import cv2
import math
from pathlib import Path
from tqdm import tqdm
from typing import Union

def file_ext(name: Union[str, Path]) -> str:
    return str(name).split('.')[-1]

def is_image_ext(fname: Union[str, Path]) -> bool:
    ext = file_ext(fname).lower()
    return f'.{ext}' in [".png", ".jpeg", ".jpg"] # type: ignore


if __name__ == '__main__':
    print("Creating a small version from preprocessed dataset...")
    # -- args --#
    seed = 1234
    N_IMAGES_TO_SELECT = 10000 
    source_dataset_path = "path/to/source/dataset"
    new_dataset_path = "path/to/new/dataset"

    # -- script begins -- #
    all_path = sorted(source_dataset_path.rglob('*'))
    all_path = [f for f in all_path if is_image_ext(f) and os.path.isfile(f)] 

    randomness = random.Random(seed)
    img_paths = randomness.sample(all_path, min(N_IMAGES_TO_SELECT, len(all_path)))
    
    for img_path in tqdm(img_paths):
        image = cv2.imread(img_path)
        
        relative_path = os.path.relpath(img_path, source_dataset_path)
        new_img_path = new_dataset_path / relative_path
        os.makedirs(new_img_path.parent, exist_ok=True)
        cv2.imwrite(new_img_path, image)