import os, sys
import numpy as np
import argparse
import objaverse
import json
import random
from pathlib import Path
from PIL import Image
from tqdm import tqdm

def fix_interactive():
    if sys.argv[0].split('/')[-1] == 'ipykernel_launcher.py':
        print("Running in interactive window...")
        sys.argv = ['']

if __name__ == '__main__':


    DATA_DIR = Path("path/to/data/dir")

    fix_interactive()
    parser = argparse.ArgumentParser()
    parser.add_argument("--dataset", type=str, default="objaverse/small")
    parser.add_argument("--strategy", type=str, default="single_category")
    args = parser.parse_args()

    strategy = args.strategy
    assert strategy in ["name", "category", "lvis", 'single_category']
    objaverse_data_raw = DATA_DIR / args.dataset / "raw"
    dataset_map_path = DATA_DIR / args.dataset
    scene_ids = os.listdir(objaverse_data_raw)

    # Download annotations
    if strategy == "lvis":
        print(f"Downloading {len(scene_ids)} objaverse annotations...")
        annotations = objaverse.load_lvis_annotations()
        count = 0
        for scene_name, scene_ids_ in annotations.items():
            count += len(scene_ids_)
        print(f"Downloaded {count} annotations.")
        # raise NotImplementedError("This part of the code is not implemented yet.")
    elif strategy != "single_category":
        print(f"Downloading {len(scene_ids)} with strategy {args.strategy}  objaverse annotations...")
        annotations = objaverse.load_annotations(scene_ids)


    def get_lvis_annotation(annotations, scene_id):
        for scene_name, scene_ids in annotations.items():
            if scene_id in scene_ids:
                return scene_name
        return "other_categories"

    # Create dataset_map
    dataset_map = {}
    for scene_id in tqdm(scene_ids, desc=f"Creating dataset_map with strategy: {strategy}..."):
        if strategy == "name":
            scene_name = annotations[scene_id]['name']
        elif strategy == "category":
            scene_name = annotations[scene_id]['categories']
            if len(scene_name) == 0:
                scene_name = "other_categories"
            elif len(scene_name) == 1:
                scene_name = scene_name[0]['name']
            elif len(scene_name) > 1:
                scene_name = random.choice(scene_name)['name']
        elif strategy == "lvis":
            scene_name = get_lvis_annotation(annotations, scene_id)
        elif strategy == "single_category":
            scene_name = "objaverse"

        if scene_name not in dataset_map.keys():
            dataset_map[scene_name] = [scene_id]
        else:
            dataset_map[scene_name].append(scene_id)

    # Save dataset_map
    with open(dataset_map_path / "dataset_map.json", 'w') as outfile:
        json.dump(dataset_map, outfile, indent=4)